@@ -16,6 +16,7 @@
 # limitations under the License.
 
 import json
+
 import yaml
 
 from bifrost.tests import base
@@ -38,9 +39,9 @@ unused,,00000000-0000-0000-0000-000000000001,hostname0,
 192.168.1.2,,,,|
 00:01:02:03:04:06,root,undefined,192.0.2.3,2,8192,1024,
 unused,,00000000-0000-0000-0000-000000000002,hostname1,
-192.168.1.3,,,,,agent_ipmitool""".replace('\n', '').replace('|', '\n')
+192.168.1.3,,,,,ipmi""".replace('\n', '').replace('|', '\n')
         expected_hostvars = """{"hostname1":
- {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "agent_ipmitool",
+ {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "ipmi",
  "name": "hostname1", "ipv4_address": "192.168.1.3",
  "provisioning_ipv4_address": "192.168.1.3" ,"ansible_ssh_host":
  "192.168.1.3", "driver_info": {"power": {"ipmi_address": "192.0.2.3",
@@ -48,15 +49,18 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
  "ipmi_target_address": null, "ipmi_target_channel": null,
  "ipmi_transit_address": null, "ipmi_transit_channel": null}}, "nics":
  [{"mac": "00:01:02:03:04:06"}], "properties": {"ram": "8192", "cpu_arch":
- "x86_64", "disk_size": "1024", "cpus": "2"}}, "hostname0":
- {"uuid": "00000000-0000-0000-0000-000000000001", "driver": "agent_ssh",
+ "x86_64", "disk_size": "1024", "cpus": "2"}, "host_groups": ["baremetal"]},
+ "hostname0":
+ {"uuid": "00000000-0000-0000-0000-000000000001", "driver": "ipmi",
  "name": "hostname0", "ipv4_address": "192.168.1.2",
  "provisioning_ipv4_address": "192.168.1.2", "ansible_ssh_host":
- "192.168.1.2", "driver_info": {"power": {"ssh_virt_type": "virsh",
- "ssh_key_filename": "/home/ironic/.ssh/id_rsa", "ssh_username":
- "ironic", "ssh_port": 22, "ssh_address": "192.0.2.2"}}, "nics":
+ "192.168.1.2", "driver_info": {"power": {"ipmi_address": "192.0.2.2",
+ "ipmi_password": "undefined", "ipmi_username": "root",
+ "ipmi_target_address": null, "ipmi_target_channel": null,
+ "ipmi_transit_address": null, "ipmi_transit_channel": null}}, "nics":
  [{"mac": "00:01:02:03:04:05"}], "properties": {"ram": "8192",
- "cpu_arch": "x86_64", "disk_size": "512", "cpus": "1"}}}""".replace('\n', '')
+ "cpu_arch": "x86_64", "disk_size": "512", "cpus": "1"},
+ "host_groups": ["baremetal"]}}""".replace('\n', '')
         expected_groups = """{"baremetal": {"hosts": ["hostname0",
  "hostname1"]}, "localhost": {"hosts": ["127.0.0.1"]}}""".replace('\n', '')
 
@@ -67,10 +71,10 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
     def test_csv_file_conversion_ipmi_dual_bridging(self):
         CSV = """00:01:02:03:04:06,root,undefined,192.0.2.3,2,8192,1024,
 unused,,00000000-0000-0000-0000-000000000002,hostname1,
-192.168.1.3,10,20,30,40,agent_ipmitool""".replace('\n', '').replace('|', '\n')
+192.168.1.3,10,20,30,40,ipmi""".replace('\n', '').replace('|', '\n')
 
         expected_hostvars = """{"hostname1":
- {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "agent_ipmitool",
+ {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "ipmi",
  "name": "hostname1", "ipv4_address": "192.168.1.3",
  "provisioning_ipv4_address": "192.168.1.3", "ansible_ssh_host":
  "192.168.1.3", "driver_info": {"power": {"ipmi_address": "192.0.2.3",
@@ -79,7 +83,8 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
  "ipmi_transit_address": "40", "ipmi_transit_channel": "30",
  "ipmi_bridging": "dual"}}, "nics":
  [{"mac": "00:01:02:03:04:06"}], "properties": {"ram": "8192", "cpu_arch":
- "x86_64", "disk_size": "1024", "cpus": "2"}}}""".replace('\n', '')
+ "x86_64", "disk_size": "1024", "cpus": "2"},
+ "host_groups": ["baremetal"]}}""".replace('\n', '')
 
         expected_groups = """{"baremetal": {"hosts": ["hostname1"]},
  "localhost": {"hosts": ["127.0.0.1"]}}""".replace('\n', '')
@@ -91,10 +96,10 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
     def test_csv_file_conversion_ipmi_single_bridging(self):
         CSV = """00:01:02:03:04:06,root,undefined,192.0.2.3,2,8192,1024,
 unused,,00000000-0000-0000-0000-000000000002,hostname1,
-192.168.1.3,10,20,,,agent_ipmitool""".replace('\n', '').replace('|', '\n')
+192.168.1.3,10,20,,,ipmi""".replace('\n', '').replace('|', '\n')
 
         expected_hostvars = """{"hostname1":
- {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "agent_ipmitool",
+ {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "ipmi",
  "name": "hostname1", "ipv4_address": "192.168.1.3",
  "provisioning_ipv4_address": "192.168.1.3", "ansible_ssh_host":
  "192.168.1.3", "driver_info": {"power": {"ipmi_address": "192.0.2.3",
@@ -103,7 +108,8 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
  "ipmi_transit_address": null, "ipmi_transit_channel": null,
  "ipmi_bridging": "single"}}, "nics":
  [{"mac": "00:01:02:03:04:06"}], "properties": {"ram": "8192", "cpu_arch":
- "x86_64", "disk_size": "1024", "cpus": "2"}}}""".replace('\n', '')
+ "x86_64", "disk_size": "1024", "cpus": "2"},
+ "host_groups": ["baremetal"]}}""".replace('\n', '')
 
         (groups, hostvars) = utils.bifrost_csv_conversion(CSV)
         self.assertDictEqual(json.loads(str(expected_hostvars)), hostvars)
@@ -111,10 +117,10 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
     def test_csv_file_conversion_dhcp(self):
         CSV = """00:01:02:03:04:06,root,undefined,192.0.2.3,2,8192,1024,
 unused,,00000000-0000-0000-0000-000000000002,hostname1
-,,,,,,agent_ipmitool""".replace('\n', '').replace('|', '\n')
+,,,,,,ipmi""".replace('\n', '').replace('|', '\n')
 
         expected_hostvars = """{"hostname1":
- {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "agent_ipmitool",
+ {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "ipmi",
  "name": "hostname1", "addressing_mode": "dhcp", "ipv4_address": null,
  "provisioning_ipv4_address": null,
  "driver_info": {"power": {"ipmi_address": "192.0.2.3", "ipmi_password":
@@ -122,7 +128,8 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1
  "ipmi_target_channel": null, "ipmi_transit_address": null,
  "ipmi_transit_channel": null}}, "nics":
  [{"mac": "00:01:02:03:04:06"}], "properties": {"ram": "8192", "cpu_arch":
- "x86_64", "disk_size": "1024", "cpus": "2"}}}""".replace('\n', '')
+ "x86_64", "disk_size": "1024", "cpus": "2"},
+ "host_groups": ["baremetal"]}}""".replace('\n', '')
 
         (groups, hostvars) = utils.bifrost_csv_conversion(CSV)
         self.assertDictEqual(json.loads(str(expected_hostvars)), hostvars)
@@ -134,10 +141,10 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1
         # is identical.
         CSV = """00:01:02:03:04:06,root,undefined,192.0.2.3,2,8192,1024,
 unused,,00000000-0000-0000-0000-000000000002,hostname1
-,,,,,,agent_ipmitool""".replace('\n', '')
+,,,,,,ipmi""".replace('\n', '')
 
         expected_hostvars = """{"hostname1":
- {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "agent_ipmitool",
+ {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "ipmi",
  "name": "hostname1", "addressing_mode": "dhcp", "ipv4_address": null,
  "provisioning_ipv4_address": null,
  "driver_info": {"power": {"ipmi_address": "192.0.2.3", "ipmi_password":
@@ -145,7 +152,8 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1
  "ipmi_target_channel": null, "ipmi_transit_address": null,
  "ipmi_transit_channel": null}}, "nics":
  [{"mac": "00:01:02:03:04:06"}], "properties": {"ram": "8192", "cpu_arch":
- "x86_64", "disk_size": "1024", "cpus": "2"}}}""".replace('\n', '')
+ "x86_64", "disk_size": "1024", "cpus": "2"},
+ "host_groups": ["baremetal"]}}""".replace('\n', '')
 
         (groups, hostvars) = utils.bifrost_csv_conversion(CSV)
         self.assertDictEqual(json.loads(str(expected_hostvars)), hostvars)
@@ -159,9 +167,9 @@ unused,,00000000-0000-0000-0000-000000000001,hostname0,
 192.168.1.2,,,,|
 00:01:02:03:04:06,root,undefined,192.0.2.3,2,8192,1024,
 unused,,00000000-0000-0000-0000-000000000002,hostname1,
-192.168.1.3,,,,,agent_ipmitool""".replace('\n', '').replace('|', '\n')
+192.168.1.3,,,,,ipmi""".replace('\n', '').replace('|', '\n')
         expected_hostvars = """{"hostname1":
- {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "agent_ipmitool",
+ {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "ipmi",
  "name": "hostname1", "ipv4_address": "192.168.1.3", "ansible_ssh_host":
  "192.168.1.3", "provisioning_ipv4_address": "192.168.1.3",
  "driver_info": {"power": {"ipmi_address": "192.0.2.3",
@@ -169,15 +177,18 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
  "ipmi_target_address": null, "ipmi_target_channel": null,
  "ipmi_transit_address": null, "ipmi_transit_channel": null}}, "nics":
  [{"mac": "00:01:02:03:04:06"}], "properties": {"ram": "8192", "cpu_arch":
- "x86_64", "disk_size": "1024", "cpus": "2"}}, "hostname0":
- {"uuid": "00000000-0000-0000-0000-000000000001", "driver": "agent_ssh",
+ "x86_64", "disk_size": "1024", "cpus": "2"}, "host_groups": ["baremetal"]},
+ "hostname0":
+ {"uuid": "00000000-0000-0000-0000-000000000001", "driver": "ipmi",
  "name": "hostname0", "ipv4_address": "192.168.1.2", "ansible_ssh_host":
  "192.168.1.2", "provisioning_ipv4_address": "192.168.1.2",
- "driver_info": {"power": {"ssh_virt_type": "virsh",
- "ssh_key_filename": "/home/ironic/.ssh/id_rsa", "ssh_username":
- "ironic", "ssh_port": 22, "ssh_address": "192.0.2.2"}}, "nics":
+ "driver_info": {"power": {"ipmi_address": "192.0.2.2",
+ "ipmi_password": "undefined", "ipmi_username": "root",
+ "ipmi_target_address": null, "ipmi_target_channel": null,
+ "ipmi_transit_address": null, "ipmi_transit_channel": null}}, "nics":
  [{"mac": "00:01:02:03:04:05"}], "properties": {"ram": "8192",
- "cpu_arch": "x86_64", "disk_size": "512", "cpus": "1"}}}""".replace('\n', '')
+ "cpu_arch": "x86_64", "disk_size": "512", "cpus": "1"},
+ "host_groups": ["baremetal"]}}""".replace('\n', '')
 
         (groups, hostvars) = utils.bifrost_csv_conversion(CSV)
         self.assertDictEqual(json.loads(str(expected_hostvars)), hostvars)
@@ -190,7 +201,7 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
         # that we get the same output when we pass something
         # in as YAML
         expected_hostvars = """{"hostname1":
- {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "agent_ipmitool",
+ {"uuid": "00000000-0000-0000-0000-000000000002", "driver": "ipmi",
  "name": "hostname1", "ipv4_address": "192.168.1.3", "ansible_ssh_host":
  "192.168.1.3", "provisioning_ipv4_address": "192.168.1.3",
  "driver_info": {"power": {"ipmi_address": "192.0.2.3",
@@ -198,15 +209,15 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
  "ipmi_target_address": null, "ipmi_target_channel": null,
  "ipmi_transit_address": null, "ipmi_transit_channel": null}}, "nics":
  [{"mac": "00:01:02:03:04:06"}], "properties": {"ram": "8192", "cpu_arch":
- "x86_64", "disk_size": "1024", "cpus": "2"}}, "hostname0":
- {"uuid": "00000000-0000-0000-0000-000000000001", "driver": "agent_ssh",
+ "x86_64", "disk_size": "1024", "cpus": "2"}, "host_groups":
+ ["baremetal", "nova"]}, "hostname0":
+ {"uuid": "00000000-0000-0000-0000-000000000001", "driver": "ipmi",
  "name": "hostname0", "ipv4_address": "192.168.1.2", "ansible_ssh_host":
  "192.168.1.2", "provisioning_ipv4_address": "192.168.1.2",
- "driver_info": {"power": {"ssh_virt_type": "virsh",
- "ssh_key_filename": "/home/ironic/.ssh/id_rsa", "ssh_username":
- "ironic", "ssh_port": 22, "ssh_address": "192.0.2.2"}}, "nics":
+ "driver_info": {"power": {}}, "nics":
  [{"mac": "00:01:02:03:04:05"}], "properties": {"ram": "8192",
- "cpu_arch": "x86_64", "disk_size": "512", "cpus": "1"}}}""".replace('\n', '')
+ "cpu_arch": "x86_64", "disk_size": "512", "cpus": "1"},
+ "host_groups": ["baremetal", "nova"]}}""".replace('\n', '')
         (groups, hostvars) = utils.bifrost_data_conversion(
             yaml.safe_dump(json.loads(str(expected_hostvars))))
         self.assertDictEqual(json.loads(str(expected_hostvars)), hostvars)
@@ -215,11 +226,11 @@ unused,,00000000-0000-0000-0000-000000000002,hostname1,
         input_json = """{"h0000-01":{"uuid":
 "00000000-0000-0000-0001-bad00000010","name":"h0000-01","driver_info"
 :{"power":{"ipmi_address":"10.0.0.78","ipmi_username":"ADMIN","
-ipmi_password":"ADMIN"}},"driver":"agent_ipmitool"}}""".replace('\n', '')
+ipmi_password":"ADMIN"}},"driver":"ipmi"}}""".replace('\n', '')
         expected_json = """{"h0000-01":{"uuid":
 "00000000-0000-0000-0001-bad00000010","name":"h0000-01","driver_info"
 :{"power":{"ipmi_address":"10.0.0.78","ipmi_username":"ADMIN","
-ipmi_password":"ADMIN"}},"driver":"agent_ipmitool","addressing_mode":
-"dhcp"}}""".replace('\n', '')
+ipmi_password":"ADMIN"}},"driver":"ipmi","addressing_mode":
+"dhcp","host_groups": ["baremetal"]}}""".replace('\n', '')
         (groups, hostvars) = utils.bifrost_data_conversion(input_json)
         self.assertDictEqual(json.loads(str(expected_json)), hostvars)
