@@ -77,8 +77,8 @@ cp -aL /httpboot/pxelinux.cfg/ ${LOG_LOCATION}/pxe/
 
 # Copy baremetal information
 source $HOME/openrc bifrost
-for vm in $(openstack baremetal node list -c Name -f value); do
-    openstack baremetal node show $vm >> ${LOG_LOCATION}/baremetal.txt
+for vm in $(baremetal node list -c Name -f value); do
+    baremetal node show $vm >> ${LOG_LOCATION}/baremetal.txt
 done
 
 if [ -d "/var/log/ironic" ]; then
