@@ -49,7 +49,7 @@ case ${ID,,} in
         [python3-devel]=libpython3-dev
         [python3-pip]=python3-pip
     )
-    EXTRA_PKG_DEPS=( python3-venv )
+    EXTRA_PKG_DEPS=( python3-venv python3-setuptools )
     sudo apt-get update
     # NOTE(dtantsur): workaround for segfault when installing cryptography:
     # https://github.com/pyca/cryptography/issues/3815
@@ -124,13 +124,21 @@ if [ -n "${VENV-}" ]; then
 fi
 
 # Install the rest of required packages using bindep
-sudo -H -E ${PIP} install bindep
+if [ -n "${VENV-}" ]; then
+    ${PIP} install bindep
+else
+    sudo -H -E ${PIP} install bindep
+fi
 
 echo "Using Bindep to install binary dependencies..."
 # bindep returns 1 if packages are missing
 bindep -b &> /dev/null || ${INSTALLER_CMD} $(bindep -b)
 
 echo "Installing Python requirements"
-sudo -H -E ${PIP} install -r "$(dirname $0)/../requirements.txt"
+if [ -n "${VENV-}" ]; then
+    ${PIP} install -r "$(dirname $0)/../requirements.txt"
+else
+    sudo -H -E ${PIP} install -r "$(dirname $0)/../requirements.txt"
+fi
 
 echo "Completed installation of basic dependencies."
